import maya.cmds as cmds
import webbrowser

def select_node(*args):
    node_name = cmds.textField('nodeNameField', query=True, text=True)
    if cmds.objExists(node_name):
        cmds.select(node_name, replace=True)
    else:
        cmds.warning(f"ノード '{node_name}' が見つかりません。")
        cmds.inViewMessage(assistMessage=f"ノード '{node_name}' が見つかりません。",
                           pos='midCenter', fade=True)

def open_help(*args):
    webbrowser.open('https://kimstation.com/')

def create_ui():
    if cmds.window("nodeSelectorWindow", exists=True):
        cmds.deleteUI("nodeSelectorWindow")
    
    window = cmds.window("nodeSelectorWindow", title="SelectByName",
                         widthHeight=(405, 100))
    
    main_layout = cmds.columnLayout()
    
    # タイトルとヘルプアイコンを横に並べるための行レイアウト
    title_row = cmds.rowLayout(numberOfColumns=2, columnWidth2=(385, 20), adjustableColumn=1, parent=main_layout)
    cmds.text(label="SelectByName", font="boldLabelFont", align="left", parent=title_row)
    cmds.iconTextButton(style='iconOnly', image1='help.png', width=20, height=20, 
                        command=open_help, annotation="ヘルプを開く", parent=title_row)
    
    cmds.setParent(main_layout)
    
    cmds.text(label="ノード名を入力してください:")
    cmds.textField('nodeNameField', width=400)
    cmds.separator(style="none", height=10)
    cmds.button(label="選択", command=select_node, width=100)
    
    cmds.showWindow(window)

create_ui()